@@ -72,13 +72,20 @@ AppEntry::AppEntry(AbstractModel *owner, const QString &id) : AbstractEntry(owne
     }
 
     if (m_service) {
-        init((NameFormat)qobject_cast<AppsModel* >(owner->rootModel())->appNameFormat());
+        init((NameFormat)owner->rootModel()->property("appNameFormat").toInt());
     }
 }
 
 void AppEntry::init(NameFormat nameFormat)
 {
     m_name = nameFromService(m_service, nameFormat);
+
+    if (nameFormat == GenericNameOnly) {
+        m_description = nameFromService(m_service, NameOnly);
+    } else {
+        m_description = nameFromService(m_service, GenericNameOnly);
+    }
+
     m_icon = QIcon::fromTheme(m_service->icon(), QIcon::fromTheme("unknown"));
 
     if (!m_appletInterface) {
@@ -107,6 +114,11 @@ QString AppEntry::name() const
     return m_name;
 }
 
+QString AppEntry::description() const
+{
+    return m_description;
+}
+
 KService::Ptr AppEntry::service() const
 {
     return m_service;
