@@ -18,14 +18,12 @@
 
 #include "keyboard_daemon.h"
 
+#include <QAction>
 #include <QX11Info>
 #include <QtDBus/QtDBus>
 #include <QProcess>
 
 #include <kpluginfactory.h>
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kglobalsettings.h>
 
 #include "x11_helper.h"
 #include "xinput_helper.h"
@@ -38,8 +36,9 @@
 #include "layout_memory_persister.h"
 #include "layouts_menu.h"
 
-
-K_PLUGIN_FACTORY(KeyboardFactory, registerPlugin<KeyboardDaemon>();)
+K_PLUGIN_FACTORY_WITH_JSON(KeyboardFactory,
+                           "keyboard.json",
+                           registerPlugin<KeyboardDaemon>();)
 
 KeyboardDaemon::KeyboardDaemon(QObject *parent, const QList<QVariant>&)
 	: KDEDModule(parent),
@@ -108,8 +107,8 @@ void KeyboardDaemon::configureKeyboard()
 void KeyboardDaemon::configureMouse()
 {
     QStringList modules;
-    modules << "mouse";
-    QProcess::startDetached("kcminit", modules);
+    modules << QStringLiteral("mouse");
+    QProcess::startDetached(QStringLiteral("kcminit"), modules);
 }
 
 void KeyboardDaemon::setupTrayIcon()
@@ -131,12 +130,10 @@ void KeyboardDaemon::registerShortcut()
 	if( actionCollection == NULL ) {
 		actionCollection = new KeyboardLayoutActionCollection(this, false);
 
-		QAction* toggleLayoutAction = actionCollection->getToggeAction();
-		connect(toggleLayoutAction, SIGNAL(triggered()), this, SLOT(switchToNextLayout()));
+		QAction* toggleLayoutAction = actionCollection->getToggleAction();
+		connect(toggleLayoutAction, &QAction::triggered, this, &KeyboardDaemon::switchToNextLayout);
 		actionCollection->loadLayoutShortcuts(keyboardConfig.layouts, rules);
 		connect(actionCollection, SIGNAL(actionTriggered(QAction*)), this, SLOT(setLayout(QAction*)));
-
-		connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this, SLOT(globalSettingsChanged(int)));
     }
 }
 
@@ -144,10 +141,8 @@ void KeyboardDaemon::unregisterShortcut()
 {
 	// register KDE keyboard shortcut for switching layouts
     if( actionCollection != NULL ) {
-        disconnect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this, SLOT(globalSettingsChanged(int)));
-
 		disconnect(actionCollection, SIGNAL(actionTriggered(QAction*)), this, SLOT(setLayout(QAction*)));
-        disconnect(actionCollection->getToggeAction(), SIGNAL(triggered()), this, SLOT(switchToNextLayout()));
+        disconnect(actionCollection->getToggleAction(), &QAction::triggered, this, &KeyboardDaemon::switchToNextLayout);
 
         delete actionCollection;
         actionCollection = NULL;
@@ -159,10 +154,10 @@ void KeyboardDaemon::registerListeners()
 	if( xEventNotifier == NULL ) {
 		xEventNotifier = new XInputEventNotifier();
 	}
-	connect(xEventNotifier, SIGNAL(newPointerDevice()), this, SLOT(configureMouse()));
-	connect(xEventNotifier, SIGNAL(newKeyboardDevice()), this, SLOT(configureKeyboard()));
-	connect(xEventNotifier, SIGNAL(layoutMapChanged()), this, SLOT(layoutMapChanged()));
-	connect(xEventNotifier, SIGNAL(layoutChanged()), this, SLOT(layoutChanged()));
+	connect(xEventNotifier, &XInputEventNotifier::newPointerDevice, this, &KeyboardDaemon::configureMouse);
+	connect(xEventNotifier, &XInputEventNotifier::newKeyboardDevice, this, &KeyboardDaemon::configureKeyboard);
+	connect(xEventNotifier, &XEventNotifier::layoutMapChanged, this, &KeyboardDaemon::layoutMapChanged);
+	connect(xEventNotifier, &XEventNotifier::layoutChanged, this, &KeyboardDaemon::layoutChanged);
 	xEventNotifier->start();
 }
 
@@ -170,19 +165,10 @@ void KeyboardDaemon::unregisterListeners()
 {
 	if( xEventNotifier != NULL ) {
 		xEventNotifier->stop();
-		disconnect(xEventNotifier, SIGNAL(newPointerDevice()), this, SLOT(configureMouse()));
-		disconnect(xEventNotifier, SIGNAL(newKeyboardDevice()), this, SLOT(configureKeyboard()));
-		disconnect(xEventNotifier, SIGNAL(layoutChanged()), this, SLOT(layoutChanged()));
-		disconnect(xEventNotifier, SIGNAL(layoutMapChanged()), this, SLOT(layoutMapChanged()));
-	}
-}
-
-void KeyboardDaemon::globalSettingsChanged(int category)
-{
-	if ( category == KGlobalSettings::SETTINGS_SHORTCUTS) {
-//TODO: optimize this? seems like we'll get configReload and globalShortcuts from kcm so we'll reconfigure twice
-		unregisterShortcut();
-		registerShortcut();
+		disconnect(xEventNotifier, &XInputEventNotifier::newPointerDevice, this, &KeyboardDaemon::configureMouse);
+		disconnect(xEventNotifier, &XInputEventNotifier::newKeyboardDevice, this, &KeyboardDaemon::configureKeyboard);
+		disconnect(xEventNotifier, &XEventNotifier::layoutChanged, this, &KeyboardDaemon::layoutChanged);
+		disconnect(xEventNotifier, &XEventNotifier::layoutMapChanged, this, &KeyboardDaemon::layoutMapChanged);
 	}
 }
 
@@ -220,10 +206,10 @@ void KeyboardDaemon::switchToNextLayout()
         LayoutUnit newLayout = X11Helper::getCurrentLayout();
 
         QDBusMessage msg = QDBusMessage::createMethodCall(
-        QLatin1Literal("org.kde.plasmashell"),
-        QLatin1Literal("/org/kde/osdService"),
-        QLatin1Literal("org.kde.osdService"),
-        QLatin1Literal("kbdLayoutChanged"));
+        QStringLiteral("org.kde.plasmashell"),
+        QStringLiteral("/org/kde/osdService"),
+        QStringLiteral("org.kde.osdService"),
+        QStringLiteral("kbdLayoutChanged"));
 
         msg.setArguments(QList<QVariant>() << newLayout.getDisplayName());
         QDBusConnection::sessionBus().asyncCall(msg);
@@ -231,7 +217,7 @@ void KeyboardDaemon::switchToNextLayout()
 
 bool KeyboardDaemon::setLayout(QAction* action)
 {
-	if( action == actionCollection->getToggeAction() )
+	if( action == actionCollection->getToggleAction() )
 		return false;
 
 	LayoutUnit layoutUnit(action->data().toString());
