@@ -45,11 +45,11 @@ void set_repeatrate(int delay, double rate)
 	XkbDescPtr xkb = XkbAllocKeyboard();
 	if (xkb) {
 		Display* dpy = QX11Info::display();
-		//int res = 
+		//int res =
 		XkbGetControls(dpy, XkbRepeatKeysMask, xkb);
 		xkb->ctrls->repeat_delay = delay;
 		xkb->ctrls->repeat_interval = (int)floor(1000/rate + 0.5);
-		//res = 
+		//res =
 		XkbSetControls(dpy, XkbRepeatKeysMask, xkb);
         XkbFreeKeyboard(xkb, 0, true);
 		return;
@@ -75,20 +75,20 @@ int set_repeat_mode(TriState keyboardRepeatMode)
 
 void init_keyboard_hardware()
 {
-    KConfigGroup config(KSharedConfig::openConfig( "kcminputrc" ), "Keyboard");
+    KConfigGroup config(KSharedConfig::openConfig( QStringLiteral("kcminputrc") ), "Keyboard");
 
 	QString keyRepeatStr = config.readEntry("KeyboardRepeating", TriStateHelper::getString(STATE_ON));
 	TriState keyRepeat = STATE_UNCHANGED;
-	if( keyRepeatStr == "true" || keyRepeatStr == TriStateHelper::getString(STATE_ON) ) {
+	if( keyRepeatStr == QLatin1String("true") || keyRepeatStr == TriStateHelper::getString(STATE_ON) ) {
 		keyRepeat = STATE_ON;
 	}
-	else if( keyRepeatStr == "false" || keyRepeatStr == TriStateHelper::getString(STATE_OFF) ) {
+	else if( keyRepeatStr == QLatin1String("false") || keyRepeatStr == TriStateHelper::getString(STATE_OFF) ) {
 		keyRepeat = STATE_OFF;
 	}
 
 	if( keyRepeat == STATE_ON ) {
-		int delay_ = config.readEntry("RepeatDelay", 660);
-		double rate_ = config.readEntry("RepeatRate", 25.);
+		int delay_ = config.readEntry("RepeatDelay", DEFAULT_REPEAT_DELAY);
+		double rate_ = config.readEntry("RepeatRate", DEFAULT_REPEAT_RATE);
 		set_repeatrate(delay_, rate_);
 	}
 
